@@ -17,7 +17,7 @@
 #'
 #' Use case *(2)* assumes a more complex structure of study data and meta data.
 #' The study data comprise so-called intro-variables (either TRUE/FALSE or codes
-#' for non-participation). The column KEY_STUDY_SEGMENT in the metadata is
+#' for non-participation). The column `PART_VAR` in the metadata is
 #' filled by variable-IDs indicating for each variable the respective
 #' intro-variable. This structure has the benefit that subsequent calculation of
 #' item missingness obtains correct denominators for the calculation of
@@ -26,7 +26,7 @@
 #' @details
 #' ### Implementation and use of thresholds
 #' This implementation uses one threshold to discriminate critical from
-#' non-critical values. If direction is high than all values below the
+#' non-critical values. If direction is above than all values below the
 #' threshold_value are normal (displayed in dark blue in the plot and flagged
 #' with GRADING = 0 in the dataframe). All values above the threshold_value are
 #' considered critical. The more they deviate from the threshold the displayed
@@ -34,7 +34,7 @@
 #' 1 in the summary data frame. By default, highest values are always shown in
 #' dark red irrespective of the absolute deviation.
 #'
-#' If direction is low than all values above the threshold_value are normal
+#' If direction is below than all values above the threshold_value are normal
 #' (displayed in dark blue, GRADING = 0).
 #'
 #' ### Hint
@@ -55,10 +55,28 @@
 #' @param threshold_value [numeric] from=0 to=100. a numerical value ranging
 #'                                                 from 0-100
 #' @param direction [enum] low | high. "high" or "low", i.e. are deviations
-#'                                     above/below the threshold critical
+#'                                     above/below the threshold critical. This argument is deprecated and replaced by *color_gradient_direction*.
+#' @param color_gradient_direction [enum] above | below. "above" or "below", i.e. are deviations
+#'                                     above or below the threshold critical? (default: above)
 #' @param exclude_roles [variable roles] a character (vector) of variable roles
 #'                                       not included
 #'
+#' @param expected_observations [enum] HIERARCHY | ALL | SEGMENT. If ALL, all
+#'                                     observations are expected to comprise
+#'                                     all study segments. If SEGMENT, the
+#'                                     `PART_VAR` is expected to point
+#'                                     to a variable with values of 0 and 1,
+#'                                     indicating whether the variable was
+#'                                     expected to be observed for each data
+#'                                     row. If HIERARCHY, this is also
+#'                                     checked recursively, so, if a variable
+#'                                     points to such a participation variable,
+#'                                     and that other variable does has also
+#'                                     a `PART_VAR` entry pointing
+#'                                     to a variable, the observation of the
+#'                                     initial variable is only
+#'                                     expected, if both segment variables are
+#'                                     1.
 #'
 #' @return a list with:
 #'   - `SummaryData`: data frame about segment missingness
@@ -74,11 +92,19 @@
 com_segment_missingness <- function(study_data, meta_data, group_vars = NULL,
                                     strata_vars = NULL, label_col,
                                     threshold_value,
-                                    direction, exclude_roles = "process") {
+                                    direction, color_gradient_direction,
+                                    expected_observations = c("HIERARCHY",
+                                                              "ALL",
+                                                              "SEGMENT"),
+                                    exclude_roles = "process") {
 
   #########
   # STOPS #
   #########
+  util_expect_scalar(expected_observations, allow_more_than_one = TRUE)
+  expected_observations <- match.arg(expected_observations)
+  util_expect_scalar(expected_observations)
+
   if (missing(threshold_value) ||
       length(threshold_value) != 1 ||
       !is.numeric(threshold_value)) {
@@ -89,36 +115,72 @@ com_segment_missingness <- function(study_data, meta_data, group_vars = NULL,
     threshold_value <- 10
   }
 
-  if (missing(direction)) {
+  if (missing(color_gradient_direction)) {
     util_warning(c(
-      "No specification of threshold direction found.",
-      "The function interprets values higher the threshold as violations."),
+      "No specification of color gradient direction found.",
+      "The function interprets values above the threshold as violations."),
       applicability_problem = TRUE)
-    direction <- "high"
+    color_gradient_direction <- "above"
   }
 
-  if (length(direction) != 1) {
+  if (length(color_gradient_direction) != 1) {
     util_error(
       "Parameter %s, if not missing, should be of length 1, but not %d.",
-      dQuote("direction"), length(direction),
+      dQuote("color_gradient_direction"), length(color_gradient_direction),
       applicability_problem = TRUE)
   }
 
-  if (!(direction %in% c("low", "high"))) {
+  if (!(color_gradient_direction %in% c("above", "below"))) {
     util_error(
       "Parameter %s should be either %s or %s, but not %s.",
-      dQuote("direction"),
-      dQuote("low"), dQuote("high"), dQuote(direction),
+      dQuote("color_gradient_direction"),
+      dQuote("above"), dQuote("below"), dQuote(color_gradient_direction),
       applicability_problem = TRUE
     )
   }
 
+  if (!(missing(direction))) {
+    if (direction %in% c("high", "low")) {
+      if ((direction == "low" && color_gradient_direction == "above") ||
+          (direction == "high" && color_gradient_direction == "below")) {
+        util_error(
+          "Conflicting options for %s and %s (%s is deprecated).",
+          dQuote("color_gradient_direction"),
+          dQuote("direction"), dQuote("direction"),
+          applicability_problem = TRUE
+        )
+      } else {
+        util_warning("%s is deprecated.", dQuote("direction"),
+                     applicability_problem = FALSE)
+      }
+    } else {
+      util_warning("%s is deprecated.", dQuote("direction"),
+                   applicability_problem = FALSE)
+    }
+  }
+
+
   ####################
   # PREPS AND CHECKS #
   ####################
 
   # map meta to study
-  util_prepare_dataframes()
+  prep_prepare_dataframes()
+
+  if (expected_observations != "ALL" && !(PART_VAR %in%
+                                          colnames(meta_data))) {
+    util_warning(c("For %s = %s, a column %s is needed in %s. Falling",
+                   "back to %s = %s."),
+                 sQuote("expected_observations"),
+                 dQuote(expected_observations),
+                 dQuote(PART_VAR),
+                 sQuote("meta_data"),
+                 sQuote("expected_observations"),
+                 dQuote("ALL"),
+                 applicability_problem = TRUE
+    )
+    expected_observations <- "ALL"
+  }
 
   # correct variable usage
   util_correct_variable_use("strata_vars",
@@ -210,52 +272,87 @@ com_segment_missingness <- function(study_data, meta_data, group_vars = NULL,
     util_warning(
       c("VARIABLE_ROLE has not been defined in the metadata,",
         "therefore all variables within segments are used."),
-      applicability_problem = TRUE)
+      applicability_problem = TRUE)# TODO: PART_VAR or STUDY_SEGMENT
   }
 
   # Which segments?
-  if (!("KEY_STUDY_SEGMENT" %in% names(meta_data))) {
-    util_error("Metadata do not contain the column KEY_STUDY_SEGMENT.",
+  if (!(STUDY_SEGMENT %in% names(meta_data))) {
+    util_error("Metadata do not contain the column STUDY_SEGMENT",
                applicability_problem = TRUE)
   }
 
-  segs <- unique(meta_data$KEY_STUDY_SEGMENT[!(is.na(
-    meta_data$KEY_STUDY_SEGMENT))])
-  seg_names <- meta_data[[LONG_LABEL]][meta_data$VAR_NAMES %in% segs]
+  seg_names <- meta_data[[STUDY_SEGMENT]] # meta_data[[LONG_LABEL]][meta_data$VAR_NAMES %in% part_vars]
 
-  if (length(seg_names) > 0) {
-    names(segs) <- seg_names
-  } else {
-    names(segs) <- segs
+  if (!(PART_VAR %in% names(meta_data))) {
+    util_warning("Metadata do not contain the column PART_VAR",
+                 applicability_problem = TRUE)
+    pv <- seg_names
+    pv[!startsWith(pv, "PART_")] <-
+      paste0("PART_", pv[!startsWith(pv, "PART_")])
+    while (any(pv %in% c(meta_data[[VAR_NAMES]],
+                         meta_data[[LABEL]],
+                         meta_data[[label_col]])
+    )) {
+      pv[pv %in% c(meta_data[[VAR_NAMES]],
+                   meta_data[[LABEL]],
+                   meta_data[[label_col]])] <-
+        paste0("_", pv[pv %in% c(meta_data[[VAR_NAMES]],
+                            meta_data[[LABEL]],
+                            meta_data[[label_col]])], "_")
+    }
+    meta_data[[PART_VAR]] <- pv
   }
 
-  # browser()
+  part_vars <- meta_data[[PART_VAR]]
+  names(part_vars) <- seg_names
+
+  keep <- !is.na(part_vars) & !is.na(seg_names)
+
+  part_vars <- part_vars[keep]
+
+  part_vars <- part_vars[!duplicated(part_vars)]
+
+  sn <- setNames(nm = unique(seg_names))
+  sn <- sn[!is.na(sn)]
+
   # determine which vars per segment
-  var_sets <- list()
-  for (i in seq_along(segs)) {
-    if (isFALSE(exclude_roles)) {
-      meta_data_excl <- meta_data[!(meta_data$VAR_NAMES %in% segs), ]
-      var_sets[[i]] <-
-        meta_data_excl[[label_col]][meta_data_excl$KEY_STUDY_SEGMENT == segs[i]]
-    } else {
-      meta_data_excl <-
-        meta_data[!(meta_data[[VARIABLE_ROLE]] %in% exclude_roles) &
-                    !(meta_data$VAR_NAMES %in% segs), ]
-      var_sets[[i]] <-
-        meta_data_excl[[label_col]][meta_data_excl$KEY_STUDY_SEGMENT ==
-                                      segs[i]][!is.na(meta_data_excl[[
-                                        label_col]][
-                                          meta_data_excl$KEY_STUDY_SEGMENT ==
-                                            segs[i]])]
+  var_sets <- lapply(sn, util_get_vars_in_segment,
+               meta_data = meta_data,
+               label_col = label_col)
+
+  # remove all part_vars
+  if (TRUE) {
+    remove_part_vars <- function(vars, meta_data, label_col) {
+      v <- util_map_labels(vars, meta_data, to = VAR_NAMES, from = label_col)
+      vars[!(v %in% part_vars)]
     }
+    var_sets <- lapply( var_sets, remove_part_vars,
+                        meta_data = meta_data,
+                        label_col = label_col)
+  }
+
+  # remove variables excluded by roles
+  if (!isFALSE(exclude_roles)) {
+    remove_roles <- function(vars, meta_data, label_col) {
+      roles <- util_map_labels(vars,
+                               meta_data = meta_data,
+                               to = VARIABLE_ROLE,
+                               from = label_col)
+      vars[!(roles %in% exclude_roles)]
+    }
+    var_sets <- lapply( var_sets, remove_roles,
+                        meta_data = meta_data,
+                        label_col = label_col)
   }
 
   # Which groups?
   if (length(group_vars) > 0) {
+    is_grouped <- TRUE
     # No. of group levels and labels
     ds1[[group_vars]] <- util_assign_levlabs(
       variable = ds1[[group_vars]],
-      string_of_levlabs = meta_data$VALUE_LABELS[meta_data$LABEL == group_vars],
+      string_of_levlabs = meta_data[[VALUE_LABELS]][meta_data[[label_col]] ==
+                                                   group_vars],
       splitchar = SPLIT_CHAR,
       assignchar = "="
     )
@@ -267,6 +364,7 @@ com_segment_missingness <- function(study_data, meta_data, group_vars = NULL,
     # missings in grouping variable?
     ds1 <- ds1[!is.na(ds1[[group_vars]]), ]
   } else {
+    is_grouped <- FALSE
     gr <- 1
     group_vars <- "Group"
     ds1$Group <- 1
@@ -284,7 +382,7 @@ com_segment_missingness <- function(study_data, meta_data, group_vars = NULL,
 
     ds1[[strata_vars]] <- util_assign_levlabs(
       variable = ds1[[strata_vars]],
-      string_of_levlabs = meta_data$VALUE_LABELS[meta_data$LABEL ==
+      string_of_levlabs = meta_data[[VALUE_LABELS]][meta_data[[label_col]] ==
                                                    strata_vars],
       splitchar = SPLIT_CHAR,
       assignchar = "="
@@ -296,11 +394,11 @@ com_segment_missingness <- function(study_data, meta_data, group_vars = NULL,
 
   # create result dataframe by factor combinations
   if (length(strata_vars) == 0) {
-    res_df <- expand.grid(Group = gr, Examinations = names(segs))
+    res_df <- expand.grid(Group = gr, Examinations = names(var_sets))
     colnames(res_df) <- c(group_vars, "Examinations")
   } else {
     res_df <- expand.grid(
-      Strata = strata, Group = gr, Examinations = names(segs),
+      Strata = strata, Group = gr, Examinations = names(var_sets),
       stringsAsFactors = TRUE
     )
     colnames(res_df) <- c(strata_vars, group_vars, "Examinations")
@@ -318,30 +416,46 @@ com_segment_missingness <- function(study_data, meta_data, group_vars = NULL,
   Ms <- c()
 
   if (length(strata_vars) == 0) {
-    for (j in seq_along(segs)) {
+    for (j in seq_along(var_sets)) {
       for (i in seq_along(gr)) {
-        Ns <- c(Ns, dim(ds1[ds1[[group_vars]] == gr[i], ])[1])
-        Ms <- c(Ms, sum(apply(ds1[ds1[[group_vars]] == gr[i],
-                                  c(as.character(unlist(var_sets[j]))),
-                                  drop = FALSE], 1, myfun)))
+        one_var_from_seg_w_r_o_g <- var_sets[[j]][[1]] # empty var set is impossible, since segments are read from item-level-metadata here. so, the first one could represent for expected observations the whole segment.
+        check_df <- ds1[
+          util_observation_expected(rv = one_var_from_seg_w_r_o_g,
+                                    study_data = ds1,
+                                    meta_data = meta_data,
+                                    label_col = label_col,
+                                    expected_observations =
+                                      expected_observations) &
+            ds1[[group_vars]] == gr[i],
+          c(as.character(unlist(var_sets[j]))),
+          drop = FALSE]
+        Ns <- c(Ns, nrow(check_df))
+        Ms <- c(Ms, sum(apply(check_df, 1, myfun)))
       }
     }
   } else {
     for (i in seq_along(strata)) {
       for (j in seq_along(gr)) {
-        for (k in seq_along(segs)) {
-          Ns <- c(Ns, dim(ds1[ds1[[strata_vars]] == strata[i] &
-                                ds1[[group_vars]] == gr[j], ])[1])
-          Ms <- c(Ms, sum(apply(ds1[
+        for (k in seq_along(var_sets)) {
+          one_var_from_seg_w_r_o_g <- var_sets[[k]][[1]] # empty var set is impossible, since segments are read from item-level-metadata here. so, the first one could represent for expected observations the whole segment.
+          check_df <-
+            ds1[util_observation_expected(rv = one_var_from_seg_w_r_o_g,
+                                      study_data = ds1,
+                                      meta_data = meta_data,
+                                      label_col = label_col,
+                                      expected_observations =
+                                        expected_observations) &
             ds1[[strata_vars]] == strata[i] & ds1[[group_vars]] == gr[j],
-            c(as.character(unlist(var_sets[k])))
-          ], 1, myfun)))
+          c(as.character(unlist(var_sets[k])))
+          ]
+          Ns <- c(Ns, nrow(check_df))
+          Ms <- c(Ms, sum(apply(check_df, 1, myfun)))
         }
       }
     }
   }
 
-  res_df$"No. of Participants" <- Ns
+  res_df$"No. of Participants" <- Ns # TODO: Write an indicator for segments expected to be empty according to some intro variable
   res_df$"No. of missing segments" <- Ms
   res_df$"(%) of missing segments" <- round(res_df$`No. of missing segments` /
                                               res_df$`No. of Participants` *
@@ -349,9 +463,12 @@ com_segment_missingness <- function(study_data, meta_data, group_vars = NULL,
   res_df$"(%) of missing segments" <-
     as.numeric(res_df$"(%) of missing segments")
   res_df$threshold <- threshold_value
-  res_df$direction <- direction
+  res_df$direction <- color_gradient_direction
 
-  if (direction == "high") {
+  res_df$"(%) of missing segments"[
+    !is.finite(res_df$"(%) of missing segments")] <- NA_real_ # to avoid Inf %
+
+  if (color_gradient_direction == "above") {
     res_df$GRADING <- ifelse(res_df$"(%) of missing segments" >
                                threshold_value, 1, 0)
   } else {
@@ -359,47 +476,74 @@ com_segment_missingness <- function(study_data, meta_data, group_vars = NULL,
                                threshold_value, 1, 0)
   }
 
-  # PLOT
-  inversion <- ifelse(direction == "low", 1, 0)
+  # plot
+  inversion <- ifelse(color_gradient_direction == "below", 1, 0)
 
   # order result data frame by grouping variable
   if (length(strata_vars) == 0) {
     # order result data frame by grouping variable
     res_df <- res_df[order(res_df[[group_vars]]), ]
-    p <- util_heatmap_1th(
-      df = res_df, cat_vars = cvs, values = "(%) of missing segments",
-      right_intv = TRUE, threshold = threshold_value,
-      invert = inversion
-    )$SummaryPlot
-  } else {
+    if (!is_grouped) {
+      repsumtab <- res_df[, c("Examinations",
+                              "No. of missing segments",
+                              "No. of Participants")]
+      colnames(repsumtab)[c(1,3)] <- c("Variables", "N")
+      attr(repsumtab, "higher_means") <- ifelse(
+        color_gradient_direction == "above",
+        "worse",
+        "")
+      class(repsumtab) <- union("ReportSummaryTable", class(repsumtab))
+      p <- print(repsumtab, view = FALSE)
+    } else { # TODO: Implemen t something useful in print.ReportSummaryTable
+      p <- util_heatmap_1th(
+       df = res_df, cat_vars = cvs, values = "(%) of missing segments",
+       right_intv = TRUE, threshold = threshold_value,
+       invert = inversion
+      )$SummaryPlot
+      repsumtab <- NULL
+    }
+  } else { # TODO: Implemen t something useful in print.ReportSummaryTable
     # order result data frame by grouping variable
     res_df <- res_df[order(res_df[[strata_vars]], res_df[[group_vars]]), ]
-    p <- util_heatmap_1th(
+    # repsumtab <- res_df[, c("Examinations",
+    #                         "No. of missing segments",
+    #                         "No. of Participants")]
+    # colnames(repsumtab)[c(1,3)] <- c("Variables", "N")
+    # attr(repsumtab, "higher_means") <- ifelse(
+    #   color_gradient_direction == "above",
+    #   "worse",
+    #   "")
+    # class(repsumtab) <- union("ReportSummaryTable", class(repsumtab))
+    # p <- print(repsumtab, view = FALSE))
+    p <- util_heatmap_1th( # TODO: Implemen t something useful in print.ReportSummaryTable
       df = res_df, cat_vars = cvs[-1], values = "(%) of missing segments",
       right_intv = TRUE, threshold = threshold_value,
       invert = inversion, strata = strata_vars
     )$SummaryPlot
+    repsumtab <- NULL
   }
+#
+#   suppressWarnings({
+#     # suppress wrong warnings: https://github.com/tidyverse/ggplot2/pull/4439/commits
+#     # find out size of the plot https://stackoverflow.com/a/51795017
+#     bp <- ggplot_build(p)
+#     w <- 2 * length(bp$layout$panel_params[[1]]$x$get_labels())
+#     if (w == 0) {
+#       w <- 10
+#     }
+#     w <- w + 2 +
+#       max(nchar(bp$layout$panel_params[[1]]$y$get_labels()),
+#           na.rm = TRUE)
+#     h <- 2 * length(bp$layout$panel_params[[1]]$y$get_labels())
+#     if (h == 0) {
+#       h <- 10
+#     }
+#     h <- h + 15
+#
+#     p <- util_set_size(p, width_em = w, height_em = h)
+#   })
 
-  suppressWarnings({
-    # suppress wrong warnings: https://github.com/tidyverse/ggplot2/pull/4439/commits
-    # find out size of the plot https://stackoverflow.com/a/51795017
-    bp <- ggplot_build(p)
-    w <- 2 * length(bp$layout$panel_params[[1]]$x$get_labels())
-    if (w == 0) {
-      w <- 10
-    }
-    w <- w + 2 +
-      max(nchar(bp$layout$panel_params[[1]]$y$get_labels()),
-          na.rm = TRUE)
-    h <- 2 * length(bp$layout$panel_params[[1]]$y$get_labels())
-    if (h == 0) {
-      h <- 10
-    }
-    h <- h + 15
-
-    p <- util_set_size(p, width_em = w, height_em = h)
-  })
-
-  return(list(SummaryData = res_df, SummaryPlot = p))
+  return(list(SummaryData = res_df,
+              ReportSummaryTable = repsumtab,
+              SummaryPlot = p))
 }
