@@ -11,7 +11,8 @@
 #'
 #' @param meta_data [data.frame] the data frame that contains metadata
 #'                               attributes of study data
-#' @param level [enum] level of requirement (see also [VARATT_REQUIRE_LEVELS])
+#' @param level [enum] level of requirement (see also [VARATT_REQUIRE_LEVELS]).
+#'                     set to `NULL` to deactivate the check of richness.
 #' @param character.only [logical] a logical indicating whether level can be
 #'                                 assumed to be character strings.
 #'
@@ -21,6 +22,7 @@
 #' @export
 #'
 #' @examples
+#' \dontrun{
 #' prep_check_meta_names(data.frame(VAR_NAMES = 1, DATA_TYPE = 2,
 #'                       MISSING_LIST = 3))
 #'
@@ -29,9 +31,17 @@
 #'     VAR_NAMES = 1, DATA_TYPE = 2, MISSING_LIST = 3,
 #'     LABEL = "LABEL", VALUE_LABELS = "VALUE_LABELS",
 #'     JUMP_LIST = "JUMP_LIST", HARD_LIMITS = "HARD_LIMITS",
-#'     KEY_OBSERVER = "KEY_OBSERVER", KEY_DEVICE = "KEY_DEVICE",
-#'     KEY_DATETIME = "KEY_DATETIME",
-#'     KEY_STUDY_SEGMENT = "KEY_STUDY_SEGMENT"
+#'     GROUP_VAR_OBSERVER = "GROUP_VAR_OBSERVER",
+#'     GROUP_VAR_DEVICE = "GROUP_VAR_DEVICE",
+#'     TIME_VAR = "TIME_VAR",
+#'     PART_VAR = "PART_VAR",
+#'     STUDY_SEGMENT = "STUDY_SEGMENT",
+#'     LOCATION_RANGE = "LOCATION_RANGE",
+#'     LOCATION_METRIC = "LOCATION_METRIC",
+#'     PROPORTION_RANGE = "PROPORTION_RANGE",
+#'     MISSING_LIST_TABLE = "MISSING_LIST_TABLE",
+#'     CO_VARS = "CO_VARS",
+#'     LONG_LABEL = "LONG_LABEL"
 #'   ),
 #'   RECOMMENDED
 #' )
@@ -41,15 +51,22 @@
 #'     VAR_NAMES = 1, DATA_TYPE = 2, MISSING_LIST = 3,
 #'     LABEL = "LABEL", VALUE_LABELS = "VALUE_LABELS",
 #'     JUMP_LIST = "JUMP_LIST", HARD_LIMITS = "HARD_LIMITS",
-#'     KEY_OBSERVER = "KEY_OBSERVER", KEY_DEVICE = "KEY_DEVICE",
-#'     KEY_DATETIME = "KEY_DATETIME", KEY_STUDY_SEGMENT =
-#'       "KEY_STUDY_SEGMENT",
+#'     GROUP_VAR_OBSERVER = "GROUP_VAR_OBSERVER",
+#'     GROUP_VAR_DEVICE = "GROUP_VAR_DEVICE",
+#'     TIME_VAR = "TIME_VAR",
+#'     PART_VAR = "PART_VAR",
+#'     STUDY_SEGMENT = "STUDY_SEGMENT",
+#'     LOCATION_RANGE = "LOCATION_RANGE",
+#'     LOCATION_METRIC = "LOCATION_METRIC",
+#'     PROPORTION_RANGE = "PROPORTION_RANGE",
 #'     DETECTION_LIMITS = "DETECTION_LIMITS", SOFT_LIMITS = "SOFT_LIMITS",
 #'     CONTRADICTIONS = "CONTRADICTIONS", DISTRIBUTION = "DISTRIBUTION",
 #'     DECIMALS = "DECIMALS", VARIABLE_ROLE = "VARIABLE_ROLE",
 #'     DATA_ENTRY_TYPE = "DATA_ENTRY_TYPE",
+#'     CO_VARS = "CO_VARS",
 #'     VARIABLE_ORDER = "VARIABLE_ORDER", LONG_LABEL =
-#'       "LONG_LABEL", recode = "recode"
+#'       "LONG_LABEL", recode = "recode",
+#'       MISSING_LIST_TABLE = "MISSING_LIST_TABLE"
 #'   ),
 #'   OPTIONAL
 #' )
@@ -59,14 +76,29 @@
 #'   prep_check_meta_names(data.frame(VAR_NAMES = 1, DATA_TYPE = 2,
 #'     MISSING_LIST = 3), TECHNICAL)
 #' )
-prep_check_meta_names <- function(meta_data, level, character.only = FALSE) {
+#' }
+prep_check_meta_names <- function(meta_data = "item_level", level,
+                                  character.only = FALSE) {
+  util_expect_data_frame(meta_data)
   if (missing(level)) {
     level <- VARATT_REQUIRE_LEVELS$REQUIRED
   } else {
     if (character.only) {
       level <- as.character(level)
     } else {
-      level <- as.character(substitute(expr = level))
+      lv <- substitute(expr = level)
+      if (length(lv) == 3 &&
+          as.character(lv[[1]]) == "$" &&
+          as.character(lv[[2]]) =="VARATT_REQUIRE_LEVELS")
+        util_error(
+          c("%s is called either with %s",
+            "set to %s or with names from %s without quotes."),
+          sQuote("prep_check_meta_names"),
+          sQuote("character.only"),
+          dQuote(TRUE),
+          dQuote('VARATT_REQUIRE_LEVELS')
+        )
+      level <- as.character(lv)
     }
     if (length(level) > 0) {
       level <- try(match.arg(level, choices = c(names(VARATT_REQUIRE_LEVELS),
@@ -94,14 +126,15 @@ prep_check_meta_names <- function(meta_data, level, character.only = FALSE) {
         required_atts <- util_get_var_att_names_of_level(level)
         if (!all(required_atts %in% colnames(meta_data))) {
           util_error(
-            c("Not all variable attributes of requirement level %s (%s) are",
-              "available in the meta data (%s). Missing %s"),
+            c("Missing %s: Not all variable attributes of requirement",
+              "level %s (%s) are available in the meta data (%s)."),
+            paste0(dQuote(required_atts[!(required_atts %in%
+                                            colnames(meta_data))]),
+                   collapse = ", "),
             dQuote(level),
             paste0(dQuote(required_atts), collapse = ", "),
             paste0(dQuote(colnames(meta_data)), collapse = ", "),
-            paste0(dQuote(required_atts[!(required_atts %in%
-                                            colnames(meta_data))]),
-                   collapse = ", "), applicability_problem = TRUE
+            applicability_problem = TRUE
           )
         }
         if (!all(colnames(meta_data) %in% required_atts)) {
