@@ -28,13 +28,19 @@
 #' @param .study_data if provided, use this data set as study_data
 #' @param .meta_data if provided, use this data set as meta_data
 #' @param .label_col if provided, use this as label_col
-#' @param .replace_missings replace missing codes, defaults to TRUE
+#' @param .replace_hard_limits replace `HARD_LIMIT` violations by `NA`,
+#'                             defaults to `FALSE`.
+#' @param .replace_missings replace missing codes, defaults to `TRUE`
+#' @param .sm_code missing code for `NAs`, if they have been
+#'                 re-coded by `util_combine_missing_lists`
+#' @param .allow_empty allow `ds1` to be empty. i.e., 0 rows and/or 0 columns
 #'
 #' @seealso acc_margins
 #'
 #' @return `ds1` the study data with mapped column names
 #'
 #' @examples
+#' \dontrun{
 #' acc_test1 <- function(resp_variable, aux_variable,
 #'                       time_variable, co_variables,
 #'                       group_vars, study_data, meta_data) {
@@ -89,13 +95,28 @@
 #' print(head(acc_test4(study_data = study_data, meta_data = meta_data,
 #'   label_col = LABEL)))
 #' try(acc_test2(study_data = NULL, meta_data = meta_data))
+#' }
 #'
 #' @export
 #'
 #' @importFrom rlang caller_fn
 #'
 prep_prepare_dataframes <- function(.study_data, .meta_data, .label_col,
-                                    .replace_missings) {
+                                    .replace_hard_limits,
+                                    .replace_missings, .sm_code = NULL,
+                                    .allow_empty = FALSE) {
+
+#  dimension <- substr(rlang::call_name(rlang::caller_call()), 1, 3)
+  # TODO: Add missing tables from meta_data$MISSING_LIST_TABLE
+
+  util_expect_scalar(.sm_code,
+                     check_type = util_all_is_integer,
+                     allow_null = TRUE)
+
+  if (missing(.replace_hard_limits)) .replace_hard_limits <- FALSE
+  util_expect_scalar(.replace_hard_limits, check_type = is.logical)
+
+  util_expect_scalar(.allow_empty, check_type = is.logical)
   if (!missing(.replace_missings) && (length(.replace_missings) != 1 ||
                                       !is.logical(.replace_missings) ||
                                       is.na(.replace_missings))) {
@@ -103,14 +124,15 @@ prep_prepare_dataframes <- function(.study_data, .meta_data, .label_col,
       "Called prepare_dataframes with .replace_missings not being logical(1)",
       applicability_problem = TRUE)
   }
-
+# TODO: include check for (hard) limits similar to replace_missings
   callfn <- caller_fn(1)
 
-  caller_defaults <- formals(callfn)
+  caller_defaults <- suppressWarnings(formals(callfn))
   caller_formals <- names(caller_defaults)
-  caller_has_default <-
+  caller_has_default <- suppressWarnings({
     !vapply(formals(callfn), identical, formals(function(x) {
         })[["x"]], FUN.VALUE = logical(1))
+  })
 
   if (missing(.label_col)) {
     if ("label_col" %in% caller_formals) {
@@ -150,9 +172,25 @@ prep_prepare_dataframes <- function(.study_data, .meta_data, .label_col,
       if (!eval.parent(substitute({
         missing(study_data)
       }))) {
-        .study_data <- get("study_data", parent.frame())
+        if (exists("study_data", parent.frame())) { # FIXME: Test this and the same for metadata
+          .study_data <- try(eval(quote(study_data), parent.frame()),
+                             silent = TRUE)
+          if (inherits(.study_data, "try-error")) {
+            cnd <- attr(.study_data, "condition")
+            cnd$call <- sys.call(1)
+            util_error(cnd)
+          }
+        } else {
+          util_error("object %s not found", dQuote("study_data"))
+        }
       } else if (caller_has_default[["study_data"]]) {
-        .study_data <- eval.parent(caller_defaults[["study_data"]], n = 2)
+        .study_data <- try(eval.parent(caller_defaults[["study_data"]], n = 2),
+                           silent = TRUE)
+        if (inherits(.study_data, "try-error")) {
+          cnd <- attr(.study_data, "condition")
+          cnd$call <- sys.call(1)
+          util_error(cnd)
+        }
       } else {
         .study_data <- NULL
       }
@@ -163,9 +201,16 @@ prep_prepare_dataframes <- function(.study_data, .meta_data, .label_col,
     }
   }
 
-
-  if (!is.data.frame(.study_data)) {
-    util_error("Need study data as a data frame")
+  e <- new.env(parent = environment())
+  e$study_data <- .study_data
+  .study_data <-
+    eval(
+      quote(try(util_expect_data_frame(study_data), silent = TRUE)),
+      e
+    )
+  if (inherits(.study_data, "try-error")) {
+    util_error("Need study data as a data frame: %s",
+               conditionMessage(attr(.study_data, "condition")))
   }
 
   if (missing(.meta_data)) {
@@ -173,38 +218,74 @@ prep_prepare_dataframes <- function(.study_data, .meta_data, .label_col,
       if (!eval.parent(substitute({
         missing(meta_data)
       }))) {
-        .meta_data <- get("meta_data", parent.frame())
+        if (exists("meta_data", parent.frame())) {
+          .meta_data <- try(eval(quote(meta_data), envir = parent.frame()),
+                             silent = TRUE)
+          if (inherits(.meta_data, "try-error")) {
+            cnd <- attr(.meta_data, "condition")
+            cnd$call <- sys.call(1)
+            util_error(cnd)
+          }
+        } else {
+          util_error("object %s not found", dQuote("meta_data"))
+        }
       } else if (caller_has_default[["meta_data"]]) {
-        .meta_data <- eval.parent(caller_defaults[["meta_data"]], n = 2)
+        .meta_data <- try(eval.parent(caller_defaults[["meta_data"]], n = 2),
+                          silent = TRUE)
+        if (inherits(.meta_data, "try-error")) {
+          cnd <- attr(.meta_data, "condition")
+          cnd$call <- sys.call(1)
+          util_error(cnd)
+        }
       } else {
-        util_warning(
-          c("Missing %s, try to guess a preliminary one from the data",
-            "using %s. Please consider amending this minimum guess manually."),
-          dQuote("meta_data"),
-          dQuote("prep_prepare_dataframes"),
-          applicability_problem = TRUE
-        )
-        .meta_data <- prep_study2meta(.study_data, level =
-                                        VARATT_REQUIRE_LEVELS$REQUIRED)
+        if ("item_level" %in% prep_list_dataframes()) {
+          .meta_data <- util_expect_data_frame("item_level")
+        }
+        if (missing(.meta_data) || !is.data.frame(.meta_data)) {
+          util_warning(
+            c("Missing %s, try to guess a preliminary one from the data",
+              "using %s. Please consider amending this minimum guess manually."),
+            dQuote("meta_data"),
+            dQuote("prep_prepare_dataframes"),
+            applicability_problem = TRUE
+          )
+          .meta_data <- prep_study2meta(.study_data, level =
+                                          VARATT_REQUIRE_LEVELS$RECOMMENDED)
+        }
       }
     } else if (exists("meta_data", parent.frame())) {
       .meta_data <- get("meta_data", parent.frame())
     } else {
-      util_warning(
-        c("Missing %s, try to guess a preliminary one from the data using %s.",
-          "Please consider amending this minimum guess manually."),
-        dQuote("meta_data"),
-        dQuote("prep_prepare_dataframes"),
-        applicability_problem = TRUE
-      )
-      .meta_data <- prep_study2meta(.study_data, level =
-                                      VARATT_REQUIRE_LEVELS$REQUIRED)
+      .meta_data <- data.frame()
     }
   }
 
-  # if no study_data have been provided -> error
-  if (!is.data.frame(.meta_data)) {
-    util_error("Need meta data as a data frame", applicability_problem = TRUE)
+  # if no meta_data have been provided -> error
+  e <- new.env(parent = environment())
+  e$meta_data <- .meta_data
+  .meta_data <-
+    eval(
+      quote(try(util_expect_data_frame(meta_data), silent = TRUE)),
+      e
+    )
+
+  if (inherits(.meta_data, "try-error")) {
+    util_error("Need meta data as a data frame: %s",
+               conditionMessage(attr(.meta_data, "condition")))
+  }
+
+  util_expect_data_frame(.meta_data)
+
+  if (!prod(dim(.meta_data))) {
+    util_warning(
+      c("Missing %s, try to guess a preliminary one from the data using %s.",
+        "Please consider amending this minimum guess manually."),
+      dQuote("meta_data"),
+      dQuote("prep_prepare_dataframes"),
+      applicability_problem = TRUE
+    )
+    .meta_data <- prep_study2meta(.study_data, level =
+                                    VARATT_REQUIRE_LEVELS$REQUIRED)
   }
 
   if (is.null(.label_col)) {
@@ -215,53 +296,6 @@ prep_prepare_dataframes <- function(.study_data, .meta_data, .label_col,
   meta_data <- .meta_data
   label_col <- .label_col
 
-  if (requireNamespace("tibble", quietly = TRUE)) {
-    if (tibble::is_tibble(study_data)) {
-      study_data <- as.data.frame(study_data)
-    }
-
-    if (tibble::is_tibble(meta_data)) {
-      meta_data <- as.data.frame(meta_data)
-    }
-  } else { # nocov start
-    if (inherits(study_data, "tbl_df")) {
-      util_warning(
-        paste(
-          "%s looks like a tibble. However, the package %s seems not",
-          "to be available, which is quite strange.",
-          "I cannot convert the tibble to a data.frame therefore.",
-          "Tibbles do not always work like base R data.frames (see %s),",
-          "so this can cause errors,",
-          "because %s expects %s in base R data.frames, not in tibbles."
-        ),
-        dQuote("study_data"),
-        dQuote("tibble"),
-        dQuote("https://r4ds.had.co.nz/tibbles.html#tibbles-vs.data.frame"),
-        dQuote("dataquieR"),
-        dQuote("study_data"),
-        applicability_problem = FALSE
-      )
-    }
-    if (inherits(meta_data, "tbl_df")) {
-      util_warning(
-        paste(
-          "%s looks like a tibble. However, the package %s seems not to be",
-          "available, which is quite strange.",
-          "I cannot convert the tibble to a data.frame therefore.",
-          "Tibbles do not always work like base R data.frames (see %s), so",
-          "this can cause errors,",
-          "because %s expects %s in base R data.frames, not in tibbles."
-        ),
-        dQuote("meta_data"),
-        dQuote("tibble"),
-        dQuote("https://r4ds.had.co.nz/tibbles.html#tibbles-vs.data.frame"),
-        dQuote("dataquieR"),
-        dQuote("meta_data"),
-        applicability_problem = FALSE
-      )
-    }
-  } # nocov end
-
   if (!exists("var_names")) {
     var_names <- "meta_data"
   }
@@ -288,21 +322,40 @@ prep_prepare_dataframes <- function(.study_data, .meta_data, .label_col,
     }
   )
 
+  meta_data <- prep_meta_data_v1_to_item_level_meta_data(meta_data =
+                                                           meta_data,
+                                                         verbose = FALSE,
+                                                         label_col = label_col)
+
   if (missing(.replace_missings) || .replace_missings) {
     # Are missing codes replaced?
     if (!("Codes_to_NA" %in% names(attributes(study_data)))) {
       study_data <-
-        util_replace_codes_by_NA(study_data = study_data, meta_data = meta_data,
-                                 split_char = SPLIT_CHAR)$study_data
+        util_replace_codes_by_NA(
+          study_data = study_data, meta_data = meta_data,
+          split_char = SPLIT_CHAR, sm_code = .sm_code)
     }
   }
 
+  repl_lim_viol <- quote({
+    if (.replace_hard_limits) {
+      # Are hard limit violations replaced?
+      if (!("HL_viol_to_NA" %in% names(attributes(ds1)))) {
+        ds1 <-
+          util_replace_hard_limit_violations(
+            study_data = ds1, meta_data = meta_data, label_col = label_col)
+      }
+    }
+  })
+
   # if study_data exist and metadata were already mapped then return ds1
   # directly
   if (isTRUE(attr(study_data, "MAPPED", exact = TRUE))) {
+    ds1 <- study_data
+    eval(repl_lim_viol)
     assign("study_data", study_data, parent.frame())
     assign("meta_data", meta_data, parent.frame())
-    assign("ds1", study_data, parent.frame())
+    assign("ds1", ds1, parent.frame())
     assign("label_col", label_col, parent.frame())
     return(invisible(study_data))
   }
@@ -321,8 +374,12 @@ prep_prepare_dataframes <- function(.study_data, .meta_data, .label_col,
 
     ds1 <- util_map_all(label_col = label_col, study_data = study_data,
                         meta_data = meta_data)$df
-    if (ncol(ds1) * nrow(ds1) == 0) {
-      util_error("No data left. Aborting.", applicability_problem = FALSE)
+    if (!(.allow_empty) && ncol(ds1) * nrow(ds1) == 0) {
+      util_error(
+        "No data left. Aborting, since mapping of %s on %s was not possible",
+        sQuote("meta_data"),
+        sQuote("study_data"),
+        applicability_problem = FALSE)
     }
   } else { # nocov start
     # unsupported now
@@ -345,7 +402,9 @@ prep_prepare_dataframes <- function(.study_data, .meta_data, .label_col,
                  .all - .mapped, dQuote(label_col),
                  applicability_problem = TRUE)
   } # nocov end
-  meta_data <- meta_data[meta_data[[label_col]] %in% colnames(ds1), , FALSE]
+  if (!.allow_empty) { # this would delete the meta data, if the mapping has failed totally
+    meta_data <- meta_data[meta_data[[label_col]] %in% colnames(ds1), , FALSE]
+  }
 
   if (VARIABLE_ORDER %in% colnames(meta_data)) {
     meta_data[] <- meta_data[order(meta_data[[VARIABLE_ORDER]]), , drop = FALSE]
@@ -354,12 +413,36 @@ prep_prepare_dataframes <- function(.study_data, .meta_data, .label_col,
     ds1 <- ds1[, vars, drop = FALSE]
   }
 
+  if (PART_VAR %in% colnames(meta_data)) local({
+    .kssvs <- intersect(colnames(study_data), meta_data[, PART_VAR])
+    for (rv in .kssvs) {
+      vals <- util_replace_codes_by_NA(
+        study_data = study_data[, rv, drop = FALSE],
+        meta_data = meta_data, sm_code = .sm_code)[[rv]]
+      vals <- vals[!is.na(vals)]
+      if (is.character(vals)) vals <- vals[trimws(vals) != ""]
+      vals <- suppressWarnings(as.numeric(vals))
+      if (!all(vals %in% c(0:1, NA), na.rm = TRUE)) {
+        util_warning(c(
+          "Found entries different from TRUE/FALSE/1/0 and <empty>, segment",
+          "participation is exptected, if values different from 0 are found.",
+          "For the segment indicator variable %s, a table of inadmissible",
+          "values: %s"),
+          dQuote(rv),
+          paste(capture.output(print(table(setdiff(vals, c(0:1, NA))))),
+                collapse = "\n"))
+      }
+    }
+  })
+
   attr(study_data, "Codes_to_NA") <- Codes_to_NA
   attr(ds1, "Codes_to_NA") <- Codes_to_NA
 
   attr(ds1, "MAPPED") <- TRUE
   attr(ds1, "label_col") <- label_col
 
+  eval(repl_lim_viol)
+
   assign("study_data", study_data, parent.frame())
   assign("meta_data", meta_data, parent.frame())
   assign("ds1", ds1, parent.frame())
@@ -367,3 +450,5 @@ prep_prepare_dataframes <- function(.study_data, .meta_data, .label_col,
 
   invisible(ds1)
 }
+
+.ds1_attribute_names <- c("Codes_to_NA", "MAPPED", "label_col", "HL_viol_to_NA")
