@@ -11,10 +11,10 @@
 #' - 1 data type mismatches but applicable
 #' - 2 data type matches but not applicable
 #' - 3 data type matches and applicable
-#'
+#' - 4 not applicable because of not suitable data type
 util_app_dl <- function(x, dta) {
-  if ("DETECTION_LIMITS" %in% names(x)) {
-    c1 <- ifelse(is.na(x["DETECTION_LIMITS"]), 0, 1)
+  if (DETECTION_LIMITS %in% names(x)) {
+    c1 <- ifelse(is.na(x[DETECTION_LIMITS]), 0, 1)
   } else {
     c1 <- rep(0, times = dim(x)[1])
   }
@@ -22,7 +22,8 @@ util_app_dl <- function(x, dta) {
   aa <- paste0(dta, c1)
   score <- as.numeric(recode(as.factor(aa), "00" = 0, "01" = 1,
                              "10" = 2, "11" = 3))
-  score <- ifelse(x[["DATA_TYPE"]] %in% c("float", "integer"), score, 4)
+  score <- ifelse(x[[DATA_TYPE]] %in% c(DATA_TYPES$FLOAT, DATA_TYPES$INTEGER),
+                  score, 4)
   score <- as.factor(score)
   return(score)
 }
