@@ -8,9 +8,9 @@
 #'
 #' @importFrom stats quantile IQR
 util_tukey <- function(x) {
-  xq1 <- as.numeric(quantile(x)[2])
-  xiqr <- IQR(x)
-  xq3 <- as.numeric(quantile(x)[4])
+  xq1 <- as.numeric(quantile(x, na.rm = TRUE)[2])
+  xiqr <- IQR(x, na.rm = TRUE)
+  xq3 <- as.numeric(quantile(x, na.rm = TRUE)[4])
   lth <- xq1 - 1.5 * xiqr
   uth <- xq3 + 1.5 * xiqr
   xbin <- ifelse(x < lth | x > uth, 1, 0)
