@@ -1,9 +1,9 @@
 test_that("con_limit_deviations works", {
-  Sys.setenv(TZ = 'CET')
-  load(system.file("extdata", "study_data.RData", package = "dataquieR"),
-       envir = environment())
-  load(system.file("extdata", "meta_data.RData", package = "dataquieR"),
-       envir = environment())
+  skip_on_cran() # slow, errors obvious
+  skip_if_not_installed("withr")
+  withr::local_timezone("CET")
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
   expect_warning(
     MyValueLimits <- con_limit_deviations(resp_vars  = c("AGE_0", "SBP_0",
                                                          "DBP_0", "SEX_0",
@@ -16,33 +16,35 @@ test_that("con_limit_deviations works", {
                                           limits     = "HARD_LIMITS"),
     regexp = sprintf("(%s|%s|%s|%s)",
                      paste("The variables SEX_0 have no defined limits."),
-                     paste("N = 9 values in QUEST_DT_0 have",
-                           "been below HARD_LIMIT_LOW and were removed."),
-                     paste("N = 3 values in EDUCATION_1 have been above",
-                           "HARD_LIMIT_UP and were removed."),
-                     paste("N = 24 values in SMOKE_SHOP_0 have been above",
-                           "HARD_LIMIT_UP and were removed.")
+                     paste("N = 9 values in QUEST_DT_0 lie outside hard",
+                           "limits and were removed."),
+                     paste("N = 3 values in EDUCATION_1 lie outside hard",
+                           "limits and were removed."),
+                     paste("N = 24 values in SMOKE_SHOP_0 lie outside hard",
+                           "limits and were removed.")
                      ),
     all = TRUE,
     perl = TRUE
   )
 
-  expect_equal(sum(MyValueLimits$SummaryTable$GRADING),
-               3)
+  expect_equal(sum(MyValueLimits$SummaryData$GRADING), 3)
   expect_true(all(MyValueLimits$FlaggedStudyData$QUEST_DT_0[which(as.logical(
     MyValueLimits$FlaggedStudyData$QUEST_DT_0_below_HARD))] <
       as.POSIXct("2018-01-01")))
   expect_true(all(MyValueLimits$FlaggedStudyData$QUEST_DT_0[which(!as.logical(
     MyValueLimits$FlaggedStudyData$QUEST_DT_0_below_HARD))] >=
       as.POSIXct("2018-01-01")))
+  expect_equal(rowSums(MyValueLimits$SummaryTable[, c("NUM_con_rvv_inum", "NUM_con_rvv_itdat")], na.rm = TRUE),
+               MyValueLimits$SummaryData$`Below hard limits (N)` + MyValueLimits$SummaryData$`Above hard limits (N)`)
 })
 
 test_that("con_limit_deviations and timevars with < 20 integer sec-values ok", {
-  Sys.setenv(TZ = 'CET')
-  load(system.file("extdata", "study_data.RData", package = "dataquieR"),
-       envir = environment())
-  load(system.file("extdata", "meta_data.RData", package = "dataquieR"),
-       envir = environment())
+  skip_on_cran() # slow, errors obvious
+  skip_if_not_installed("withr")
+  withr::local_timezone("CET")
+  withr::local_locale(c(LC_TIME = "en_US.UTF-8"))
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
 
   vn <- subset(meta_data, LABEL == "QUEST_DT_0", VAR_NAMES, TRUE)
 
@@ -74,11 +76,11 @@ test_that("con_limit_deviations and timevars with < 20 integer sec-values ok", {
 })
 
 test_that("con_limit_deviations works w/o resp_vars", {
-  Sys.setenv(TZ = 'CET')
-  load(system.file("extdata", "study_data.RData", package = "dataquieR"),
-       envir = environment())
-  load(system.file("extdata", "meta_data.RData", package = "dataquieR"),
-       envir = environment())
+  skip_on_cran() # slow, errors obvious
+  skip_if_not_installed("withr")
+  withr::local_timezone("CET")
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
 
   resp_vars <- c("AGE_0", "SBP_0",
                  "DBP_0", "SEX_0",
@@ -104,18 +106,18 @@ test_that("con_limit_deviations works w/o resp_vars", {
     regexp = sprintf("(%s|%s|%s|%s)",
                      paste("All variables with HARD_LIMITS in",
                            "the metadata are used."),
-                     paste("N = 9 values in QUEST_DT_0 have",
-                           "been below HARD_LIMIT_LOW and were removed."),
-                     paste("N = 3 values in EDUCATION_1 have been above",
-                           "HARD_LIMIT_UP and were removed."),
-                     paste("N = 24 values in SMOKE_SHOP_0 have been above",
-                           "HARD_LIMIT_UP and were removed.")
+                     paste("N = 9 values in QUEST_DT_0 lie outside hard",
+                           "limits and were removed."),
+                     paste("N = 3 values in EDUCATION_1 lie outside hard",
+                           "limits and were removed."),
+                     paste("N = 24 values in SMOKE_SHOP_0 lie outside hard",
+                           "limits and were removed.")
     ),
     all = TRUE,
     perl = TRUE
   )
 
-  expect_equal(sum(MyValueLimits$SummaryTable$GRADING),
+  expect_equal(sum(MyValueLimits$SummaryData$GRADING),
                3)
   expect_true(all(MyValueLimits$FlaggedStudyData$QUEST_DT_0[which(as.logical(
     MyValueLimits$FlaggedStudyData$QUEST_DT_0_below_HARD))] <
@@ -126,12 +128,12 @@ test_that("con_limit_deviations works w/o resp_vars", {
 })
 
 test_that("con_limit_deviations handles errors", {
-  Sys.setenv(TZ = 'CET')
+  skip_on_cran() # slow, errors obvious
+  skip_if_not_installed("withr")
+  withr::local_timezone("CET")
 
-  load(system.file("extdata", "study_data.RData", package = "dataquieR"),
-       envir = environment())
-  load(system.file("extdata", "meta_data.RData", package = "dataquieR"),
-       envir = environment())
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
 
   resp_vars <- c("AGE_0", "SBP_0",
                  "DBP_0", "SEX_0",
@@ -147,30 +149,20 @@ test_that("con_limit_deviations handles errors", {
   sd0 <- study_data[, resp_vars_names, FALSE]
   md0 <- meta_data[meta_data$VAR_NAMES %in% resp_vars_names, , FALSE]
   md0$JUMP_LIST <- SPLIT_CHAR # signals unambiguously no codes intentionally
-
   md0$HARD_LIMITS <- NA # no limits
 
-  expect_error(
-    MyValueLimits <- con_limit_deviations(label_col  = "LABEL",
-                                          study_data = sd0,
-                                          meta_data  = md0,
-                                          limits     = "HARD_LIMITS"),
-    regexp = "No Variables with defined HARD_LIMITS.",
-    perl = TRUE
-  )
-
-  expect_error(
+  expect_message(expect_error(
     MyValueLimits <- con_limit_deviations(resp_vars = resp_vars,
                                           label_col  = "LABEL",
                                           study_data = sd0,
                                           meta_data  = md0,
                                           limits     = "HARD_LIMITS"),
-    regexp = "No Variables with defined HARD_LIMITS.",
+    regexp = "No variables with defined HARD_LIMITS.",
     perl = TRUE
-  )
+  ),
+  regexp = "Not all entries in .+KEY_STUDY_SEGMENT.+0.+7.*")
 
   resp_vars <- meta_data$LABEL
-
   resp_vars_names <- prep_map_labels(resp_vars,
                                      meta_data,
                                      from = LABEL,
@@ -179,68 +171,40 @@ test_that("con_limit_deviations handles errors", {
   sd0 <- study_data[, resp_vars_names, FALSE]
   md0 <- meta_data[meta_data$VAR_NAMES %in% resp_vars_names, , FALSE]
   md0$JUMP_LIST <- SPLIT_CHAR # signals unambiguously no codes intentionally
-
   md0$HARD_LIMITS[md0$DATA_TYPE == DATA_TYPES$STRING] <-
     "[1; 5]" # Some unsuitable limits
 
-  expect_warning(
-      MyValueLimits <- con_limit_deviations(label_col  = "LABEL",
-                                            study_data = sd0,
-                                            meta_data  = md0,
-                                            limits     = "HARD_LIMITS"),
-    regexp = sprintf("(%s|%s|%s)",
-                     paste("Variables PSEUDO_ID, AGE_GROUP_0,",
-                           "VO2_CAPCAT_0, USR_VO2_0, USR_BP_0, USR_SOCDEM_0",
-                           "are neither numeric nor datetime and will be",
-                           "removed from analyses."),
-                     paste("N = (3|24|1066|349|9) values in",
-                "(EDUCATION_1|SMOKE_SHOP_0|PREGNANT_0|MEDICATION_0|QUEST_DT_0)",
-                "have been (above|below)",
-                "HARD_LIMIT_(UP|LOW) and were removed."),
-                     paste("All variables with HARD_LIMITS in the",
-                           "metadata are used.")
-    ),
-    all = TRUE,
+  expect_error(
+      MyValueLimits <- suppressWarnings(
+        con_limit_deviations(resp_vars = md0$LABEL, # missing, only resp_vars with suitable data type are picked by the function now.
+                             label_col  = "LABEL",
+                             study_data = sd0,
+                             meta_data  = md0,
+                             limits     = "HARD_LIMITS")),
+      regexp = paste("Variable .+PSEUDO_ID.+ .+string.+ does not have an",
+                           "allowed type"),
     perl = TRUE
   )
 
-  expect_equal(
-    sum(MyValueLimits$SummaryTable$GRADING), 5
+  sd0 <- study_data
+  sd0[[prep_map_labels("BSG_0", meta_data, VAR_NAMES, LABEL)]] <- NA
+  expect_error(
+    MyValueLimits  <- con_limit_deviations(resp_vars  = "BSG_0",
+                                         label_col  = "LABEL",
+                                         study_data = sd0,
+                                         meta_data  = meta_data,
+                                         limits     = "HARD_LIMITS"),
+    regexp = "Variable .+BSG_0.+ .+resp_vars.+ has only NA observations"
   )
-
-  md0$HARD_LIMITS <- NA # no limits
-  md0$HARD_LIMITS[md0$DATA_TYPE == DATA_TYPES$STRING] <-
-    "[1; 5]" # Only unsuitable limits
-
-  expect_warning(
-    expect_error(
-      MyValueLimits <- con_limit_deviations(label_col  = "LABEL",
-                                            study_data = sd0,
-                                            meta_data  = md0,
-                                            limits     = "HARD_LIMITS"),
-      regexp = "No variables left, no limit checks possible.",
-      perl = FALSE
-    ),
-    regexp = sprintf("(%s|%s)",
-                     paste("Variables PSEUDO_ID, AGE_GROUP_0,",
-                           "VO2_CAPCAT_0, USR_VO2_0, USR_BP_0, USR_SOCDEM_0",
-                           "are neither numeric nor datetime and will be",
-                           "removed from analyses."),
-                     paste("All variables with HARD_LIMITS in the",
-                           "metadata are used.")
-    ),
-    all = TRUE,
-    perl = TRUE
-  )
-
 })
 
 test_that("con_limit_deviations and values < 0", {
-  Sys.setenv(TZ = 'CET')
-  load(system.file("extdata", "study_data.RData", package = "dataquieR"),
-       envir = environment())
-  load(system.file("extdata", "meta_data.RData", package = "dataquieR"),
-       envir = environment())
+  skip_on_cran() # slow, errors obvious
+  skip_if_not_installed("withr")
+  withr::local_timezone("CET")
+
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
 
   sd0 <- study_data
   x <- sd0[[prep_map_labels("EDUCATION_0", meta_data, VAR_NAMES, LABEL)]]
@@ -259,7 +223,7 @@ test_that("con_limit_deviations and values < 0", {
                                         meta_data  = md0,
                                         limits     = "HARD_LIMITS")
 
-  expect_is(MyValueLimits, "list")
+  expect_type(MyValueLimits, "list")
 
   skip_on_cran()
   skip_if_not_installed("vdiffr")
@@ -273,11 +237,12 @@ test_that("con_limit_deviations and values < 0", {
 })
 
 test_that("con_limit_deviations and values < 0 with max -1", {
-  Sys.setenv(TZ = 'CET')
-  load(system.file("extdata", "study_data.RData", package = "dataquieR"),
-       envir = environment())
-  load(system.file("extdata", "meta_data.RData", package = "dataquieR"),
-       envir = environment())
+  skip_on_cran() # slow, errors obvious
+  skip_if_not_installed("withr")
+  withr::local_timezone("CET")
+
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
 
   sd0 <- study_data
   x <- sd0[[prep_map_labels("EDUCATION_0", meta_data, VAR_NAMES, LABEL)]]
@@ -296,7 +261,7 @@ test_that("con_limit_deviations and values < 0 with max -1", {
                                         meta_data  = md0,
                                         limits     = "HARD_LIMITS")
 
-  expect_is(MyValueLimits, "list")
+  expect_type(MyValueLimits, "list")
 
   skip_on_cran()
   skip_if_not_installed("vdiffr")
@@ -309,14 +274,13 @@ test_that("con_limit_deviations and values < 0 with max -1", {
 
 })
 
-
-
 test_that("con_limit_deviations with no lower limit", {
-  Sys.setenv(TZ = 'CET')
-  load(system.file("extdata", "study_data.RData", package = "dataquieR"),
-       envir = environment())
-  load(system.file("extdata", "meta_data.RData", package = "dataquieR"),
-       envir = environment())
+  skip_on_cran() # slow, errors obvious
+  skip_if_not_installed("withr")
+  withr::local_timezone("CET")
+
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
 
   sd0 <- study_data
   x <- sd0[[prep_map_labels("EDUCATION_0", meta_data, VAR_NAMES, LABEL)]]
@@ -332,14 +296,12 @@ test_that("con_limit_deviations with no lower limit", {
                                           study_data = sd0,
                                           meta_data  = md0,
                                           limits     = "HARD_LIMITS"),
-    regexp = paste("N = 4 values in EDUCATION_0 have",
-                   "been below HARD_LIMIT_LOW and were removed."),
-    all = TRUE,
+    regexp = paste("N = 4 values in EDUCATION_0 lie outside hard limits",
+                   "and were removed."),
     perl = TRUE
   )
 
-  md0[md0$LABEL == "EDUCATION_0", HARD_LIMITS] <-
-    "[;6]"
+  md0[md0$LABEL == "EDUCATION_0", HARD_LIMITS] <- "[;6]"
 
   MyValueLimits2 <- con_limit_deviations(resp_vars  = "EDUCATION_0",
                                          label_col  = "LABEL",
@@ -347,28 +309,26 @@ test_that("con_limit_deviations with no lower limit", {
                                          meta_data  = md0,
                                          limits     = "HARD_LIMITS")
 
-  expect_equal(MyValueLimits1$SummaryTable$`Above HARD (N)`,
-               MyValueLimits2$SummaryTable$`Above HARD (N)`)
+  expect_equal(MyValueLimits1$SummaryData$`Above hard limits (N)`,
+               MyValueLimits2$SummaryData$`Above hard limits (N)`)
 
-
-  expect_equal(MyValueLimits1$SummaryTable$`Below HARD (N)`, 4)
-  expect_equal(MyValueLimits2$SummaryTable$`Below HARD (N)`, 0)
+  expect_equal(MyValueLimits1$SummaryData$`Below hard limits (N)`, 4)
+  expect_equal(MyValueLimits2$SummaryData$`Below hard limits (N)`, 0)
 })
 
 test_that("con_limit_deviations with constant data", {
-  Sys.setenv(TZ = 'CET')
-  load(system.file("extdata", "study_data.RData", package = "dataquieR"),
-       envir = environment())
-  load(system.file("extdata", "meta_data.RData", package = "dataquieR"),
-       envir = environment())
+  skip_on_cran() # slow, errors obvious
+  skip_if_not_installed("withr")
+  withr::local_timezone("CET")
+
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
 
   sd0 <- study_data
-  x <- sd0[[prep_map_labels("CRP_0", meta_data, VAR_NAMES, LABEL)]]
-
-  x <- 1.1 # with 1, even for DATA_TYPE == float variables, barplots are shown
+  sd0[[prep_map_labels("CRP_0", meta_data, VAR_NAMES, LABEL)]] <- 1.1
+  # with 1, even for DATA_TYPE == float variables, barplots are shown
   # However, we want  to test a special edge case for histograms
 
-  sd0[[prep_map_labels("CRP_0", meta_data, VAR_NAMES, LABEL)]] <- x
   md0 <- meta_data
 
   MyValueLimits  <- con_limit_deviations(resp_vars  = "CRP_0",
@@ -377,7 +337,7 @@ test_that("con_limit_deviations with constant data", {
                                          meta_data  = md0,
                                          limits     = "HARD_LIMITS")
 
-  expect_is(MyValueLimits, "list")
+  expect_type(MyValueLimits, "list")
 
   skip_on_cran()
   skip_if_not_installed("vdiffr")
@@ -390,11 +350,12 @@ test_that("con_limit_deviations with constant data", {
 })
 
 test_that("con_limit_deviations does not crash with missing codes", {
-  Sys.setenv(TZ = 'CET')
-  load(system.file("extdata", "study_data.RData", package = "dataquieR"),
-       envir = environment())
-  load(system.file("extdata", "meta_data.RData", package = "dataquieR"),
-       envir = environment())
+  skip_on_cran() # slow, errors obvious
+  skip_if_not_installed("withr")
+  withr::local_timezone("CET")
+
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
 
   sd0 <- study_data
   x <- sd0[[prep_map_labels("SBP_0", meta_data, VAR_NAMES, LABEL)]]
@@ -411,24 +372,19 @@ test_that("con_limit_deviations does not crash with missing codes", {
                                           study_data = sd0,
                                           meta_data  = md0,
                                           limits     = "HARD_LIMITS"),
-    regexp = sprintf("(%s|%s|%s)",
-                     paste("For .+SBP_0.+, I have 66505 breaks. Did you",
-                           "forget to specify some missing codes .+99999.+",
-                           "Will arbitrarily reduce the number of breaks below",
-                           "10000 to avoid rendering problems."),
-                     paste("For .+SBP_0.+. Will arbitrarily reduced the number",
-                           "of breaks to 8315 <= 10000 to avoid rendering",
-                           "problems."),
-                     paste("N = 1 values in SBP_0 have been above",
-                           "HARD_LIMIT_UP and were removed.")
+    regexp = sprintf("(%s|%s)",
+                     paste("The number of bins in the histogram were reduced",
+                           "below \\d+ bins."),
+                     paste("N = 1 values in SBP_0 lie outside hard limits",
+                           "and were removed.")
                      ),
     perl = TRUE,
     all = TRUE
   )
 
-  expect_is(MyValueLimits, "list")
-  expect_equal(MyValueLimits$SummaryTable$`Above HARD (N)`, 1)
-  expect_equal(MyValueLimits$SummaryTable$`Below HARD (N)`, 0)
+  expect_type(MyValueLimits, "list")
+  expect_equal(MyValueLimits$SummaryData$`Above hard limits (N)`, 1)
+  expect_equal(MyValueLimits$SummaryData$`Below hard limits (N)`, 0)
 
   sd0 <- study_data
   x <- sd0[[prep_map_labels("SBP_0", meta_data, VAR_NAMES, LABEL)]]
@@ -444,26 +400,19 @@ test_that("con_limit_deviations does not crash with missing codes", {
                                            study_data = sd0,
                                            meta_data  = md0,
                                            limits     = "HARD_LIMITS"),
-    regexp = sprintf("(%s|%s|%s|%s)",
-                     paste("For .+SBP_0.+, I have 66507 breaks. Did you",
-                           "forget to specify some missing codes .+1e.05.+",
-                           "or .+97.+",
-                           "Will arbitrarily reduce the number of breaks below",
-                           "10000 to avoid rendering problems."),
-                     paste("For .+SBP_0.+. Will arbitrarily reduced the number",
-                           "of breaks to 8315 <= 10000 to avoid rendering",
-                           "problems."),
-                     paste("N = 1 values in SBP_0 have been above",
-                           "HARD_LIMIT_UP and were removed."),
-                     "Removed 439 rows containing non-finite values .stat_bin.."
+    regexp = sprintf("(%s|%s)",
+                     paste("The number of bins in the histogram were reduced",
+                           "below \\d+ bins."),
+                     paste("N = 1 values in SBP_0 lie outside hard limits",
+                           "and were removed.")
     ),
     perl = TRUE,
     all = TRUE
   )
 
-  expect_is(MyValueLimits, "list")
-  expect_equal(MyValueLimits$SummaryTable$`Above HARD (N)`, 1)
-  expect_equal(MyValueLimits$SummaryTable$`Below HARD (N)`, 0)
+  expect_type(MyValueLimits, "list")
+  expect_equal(MyValueLimits$SummaryData$`Above hard limits (N)`, 1)
+  expect_equal(MyValueLimits$SummaryData$`Below hard limits (N)`, 0)
 
   skip_on_cran()
   skip_if_not(capabilities()["long.double"])
@@ -474,3 +423,146 @@ test_that("con_limit_deviations does not crash with missing codes", {
       MyValueLimits$SummaryPlotList$SBP_0)
   )
 })
+
+test_that("con_limit_deviations does not crash with strong outliers", {
+  skip_on_cran() # slow, errors obvious
+  # issue 116
+  skip_if_not_installed("withr")
+  withr::local_timezone("CET")
+
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
+
+  md0 <- meta_data
+  md0[["HARD_LIMITS"]][which(md0$LABEL == "BSG_0")] <- "[0;5000]"
+  sd0 <- study_data
+  x <- sd0[[prep_map_labels("BSG_0", meta_data, VAR_NAMES, LABEL)]]
+  x[c(2,8,92)] <- c(26027, 28097, 4031012019)
+  sd0[[prep_map_labels("BSG_0", meta_data, VAR_NAMES, LABEL)]] <- x
+  expect_warning(
+    MyValueLimits  <- con_limit_deviations(resp_vars  = "BSG_0",
+                                         label_col  = "LABEL",
+                                         study_data = sd0,
+                                         meta_data  = md0,
+                                         limits     = "HARD_LIMITS"),
+
+    regexp = sprintf("(%s|%s)",
+                     paste("The number of bins in the histogram were reduced",
+                           "below \\d+ bins."),
+                     paste("N = 3 values in BSG_0 lie outside hard limits and",
+                           "were removed.")
+    ),
+    perl = TRUE,
+    all = TRUE
+  )
+
+  expect_type(MyValueLimits, "list")
+  expect_equal(MyValueLimits$SummaryData$`Above hard limits (N)`, 3)
+  expect_equal(MyValueLimits$SummaryData$`Below hard limits (N)`, 0)
+})
+
+test_that("con_limits_deviations does not crash with NAs in datetime vars", {
+  skip_on_cran() # slow, errors obvious
+  # issue 106
+  skip_if_not_installed("withr")
+  withr::local_timezone("CET")
+
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
+
+  #sd0 <- study_data
+  #x <- sd0[[prep_map_labels("QUEST_DT_0", meta_data, VAR_NAMES, LABEL)]]
+  #any(is.na(x))
+  #length(which(is.na(x)))
+  # Variable QUEST_DT_0 already contains NA values
+  expect_warning(
+    MyValueLimits  <- con_limit_deviations(resp_vars  = "QUEST_DT_0",
+                                         label_col  = "LABEL",
+                                         study_data = study_data,
+                                         meta_data  = meta_data,
+                                         limits     = "HARD_LIMITS"),
+    regexp = paste("N = 9 values in QUEST_DT_0 lie outside hard limits",
+                   "and were removed.")
+  )
+
+  expect_type(MyValueLimits, "list")
+  expect_equal(MyValueLimits$SummaryData$`Above hard limits (N)`, 0)
+  expect_equal(MyValueLimits$SummaryData$`Below hard limits (N)`, 9)
+})
+
+test_that("con_limit_deviations works with no values within limits", {
+  skip_on_cran() # slow, errors obvious
+  skip_if_not_installed("withr")
+  withr::local_timezone("CET")
+
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
+
+  md0 <- meta_data
+  md0[["HARD_LIMITS"]][which(md0$LABEL == "BSG_0")] <- "[51.5;51.8]"
+  sd0 <- study_data
+
+  expect_warning(
+    MyValueLimits  <- con_limit_deviations(resp_vars  = "BSG_0",
+                                         label_col  = "LABEL",
+                                         study_data = sd0,
+                                         meta_data  = md0,
+                                         limits     = "HARD_LIMITS"),
+    regexp = sprintf("(%s|%s)",
+                     paste("The number of bins in the histogram were reduced",
+                           "below \\d+ bins."),
+                     paste("N = 2686 values in BSG_0 lie outside hard limits and",
+                           "were removed.")
+    ),
+    perl = TRUE,
+    all = TRUE
+  )
+
+  expect_type(MyValueLimits, "list")
+  skip_on_cran()
+  skip_if_not_installed("vdiffr")
+  skip_if_not(capabilities()["long.double"])
+  suppressWarnings(
+    vdiffr::expect_doppelganger(
+      "con_limit_deviations_nothing_within",
+      MyValueLimits$SummaryPlotList$BSG_0)
+  )
+})
+
+test_that("con_limit_deviations works with wrong datetime limits", {
+  skip_on_cran() # slow, errors obvious
+  skip_if_not_installed("withr")
+  withr::local_timezone("CET")
+
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
+
+  md0 <- meta_data
+  md0[["HARD_LIMITS"]][which(md0$LABEL == "QUEST_DT_0")] <- "[51.5;51.8]"
+  sd0 <- study_data
+
+  expect_warning(
+    MyValueLimits <- con_limit_deviations(resp_vars  = "QUEST_DT_0",
+                                          label_col  = "LABEL",
+                                          study_data = sd0,
+                                          meta_data  = md0,
+                                          limits     = "HARD_LIMITS"))
+
+  md0[["HARD_LIMITS"]][which(md0$LABEL == "QUEST_DT_0")] <-
+    "[2018-10-01; 2017-10-01]"
+  expect_warning(expect_error(
+    MyValueLimits <- con_limit_deviations(resp_vars  = "QUEST_DT_0",
+                                          label_col  = "LABEL",
+                                          study_data = sd0,
+                                          meta_data  = md0,
+                                          limits     = "HARD_LIMITS")))
+
+  md0[["HARD_LIMITS"]][which(md0$LABEL == "QUEST_DT_0")] <-
+    "[0; test]"
+  expect_warning(expect_error(
+    MyValueLimits <- con_limit_deviations(resp_vars  = "QUEST_DT_0",
+                                          label_col  = "LABEL",
+                                          study_data = sd0,
+                                          meta_data  = md0,
+                                          limits     = "HARD_LIMITS")))
+})
