@@ -1,10 +1,14 @@
 test_that("print.dataquieR_resultset works", {
+  skip_on_cran() # slow, deprecated
+  skip_if_not_installed("withr")
+  withr::local_options(dataquieR.CONDITIONS_WITH_STACKTRACE = TRUE,
+                   dataquieR.ERRORS_WITH_CALLER = TRUE,
+                   dataquieR.WARNINGS_WITH_CALLER = TRUE,
+                   dataquieR.MESSAGES_WITH_CALLER = TRUE)
   skip_on_cran() # slow test
-  skip_if_not_installed("flexdashboard")
-  load(system.file("extdata/meta_data.RData", package = "dataquieR"), envir =
-         environment())
-  load(system.file("extdata/study_data.RData", package = "dataquieR"), envir =
-         environment())
+  skip_if_not_installed("flexsiteboard")
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
 
   # don't include huge reports as RData in the package
   # Suppress warnings since we do not test dq_report
@@ -22,21 +26,16 @@ test_that("print.dataquieR_resultset works", {
                                            package = "dataquieR"
                                          ), header = TRUE, sep = "#"),
                                        show_causes = TRUE,
-                                       cause_label_df = read.csv(
-                                         system.file(
-                                           "extdata",
-                                           "Missing-Codes-2020.csv",
-                                           package = "dataquieR"),
-                                         header = TRUE, sep = ";"
-                                       )
+                                       cause_label_df = prep_get_data_frame(
+                                         "meta_data_v2|missing_table")
   ))
   env <- new.env(parent = emptyenv())
-  v <- function(x) env$file <- x
+  v <- function(x, ...) env$file <- x
   fkt <- function(report, v) {
     old <- options("viewer")
     on.exit(options(old))
     options(viewer = v)
-    print(report)
+    print(report, self_contained = TRUE)
   }
   empty_report <- as.data.frame.dataquieR_resultset(list(long_format = list()))
   class(empty_report) <- "dataquieR_resultset"
@@ -57,7 +56,7 @@ title: "dataquieR report"
 author: "`r Sys.info()[[\'user\']]`"
 date: "`r format(Sys.time(), \'%d %B, %Y\')`"
 output:
-  flexdashboard::flex_dashboard:
+  flexsiteboard::flex_site_board:
     storyboard: true
     vertical_layout: "scroll"
     orientation: "columns"
@@ -90,12 +89,17 @@ print(sprintf("ccccc=%s=ccccc", class(report)))
 # Empty
 
 ', file = tmpl)
-    .a <- readLines(print(report, template = tmpl))
-    .b <- readLines(print(report, chunk_echo = TRUE, template = tmpl))
-    .c <- readLines(print(report, chunk_error = TRUE, template = tmpl))
-    .d <- readLines(print(report, chunk_message = TRUE, template = tmpl))
-    .e <- readLines(print(report, chunk_warning = TRUE, template = tmpl))
-    .f <- readLines(print(report, output_format = NULL, template = tmpl))
+    .a <- readLines(print(report, template = tmpl, self_contained = TRUE))
+    .b <- readLines(print(report, chunk_echo = TRUE, template = tmpl,
+                          self_contained = TRUE))
+    .c <- readLines(print(report, chunk_error = TRUE, template = tmpl,
+                          self_contained = TRUE))
+    .d <- readLines(print(report, chunk_message = TRUE, template = tmpl,
+                          self_contained = TRUE))
+    .e <- readLines(print(report, chunk_warning = TRUE, template = tmpl,
+                          self_contained = TRUE))
+    .f <- readLines(print(report, output_format = NULL, template = tmpl,
+                          self_contained = TRUE))
     expect_error(print(report, output_format = NULL, template = 42),
                  regexp = "template must be a character.1.", perl = TRUE)
     expect_error(print(report, output_format = NULL, template = tmpl,
@@ -125,8 +129,7 @@ print(sprintf("ccccc=%s=ccccc", class(report)))
     expect_error(print(report, output_format = NULL, template = tmpl,
                        chunk_warning = c(TRUE, FALSE, TRUE, FALSE)),
                  regexp = "chunk_warning must be a logical.1.", perl = TRUE)
-
-    expect_true(any(grepl("lllll=6=lllll", .a)))
+    expect_true(any(grepl("lllll=9=lllll", .a)))
     expect_true(any(grepl("ccccc=dataquieR_resultset=ccccc", .a)))
     expect_true(any(grepl("pn=dataquieR", .a)))
     expect_true(any(grepl("cc=FALSE", .a)))
@@ -134,7 +137,7 @@ print(sprintf("ccccc=%s=ccccc", class(report)))
     expect_true(any(grepl("cw=FALSE", .a)))
     expect_true(any(grepl("cm=FALSE", .a)))
 
-    expect_true(any(grepl("lllll=6=lllll", .b)))
+    expect_true(any(grepl("lllll=9=lllll", .b)))
     expect_true(any(grepl("ccccc=dataquieR_resultset=ccccc", .b)))
     expect_true(any(grepl("pn=dataquieR", .b)))
     expect_true(any(grepl("cc=TRUE", .b)))
@@ -142,7 +145,7 @@ print(sprintf("ccccc=%s=ccccc", class(report)))
     expect_true(any(grepl("cw=FALSE", .b)))
     expect_true(any(grepl("cm=FALSE", .b)))
 
-    expect_true(any(grepl("lllll=6=lllll", .c)))
+    expect_true(any(grepl("lllll=9=lllll", .c)))
     expect_true(any(grepl("ccccc=dataquieR_resultset=ccccc", .c)))
     expect_true(any(grepl("pn=dataquieR", .c)))
     expect_true(any(grepl("cc=FALSE", .c)))
@@ -150,7 +153,7 @@ print(sprintf("ccccc=%s=ccccc", class(report)))
     expect_true(any(grepl("cw=FALSE", .c)))
     expect_true(any(grepl("cm=FALSE", .c)))
 
-    expect_true(any(grepl("lllll=6=lllll", .d)))
+    expect_true(any(grepl("lllll=9=lllll", .d)))
     expect_true(any(grepl("ccccc=dataquieR_resultset=ccccc", .d)))
     expect_true(any(grepl("pn=dataquieR", .d)))
     expect_true(any(grepl("cc=FALSE", .d)))
@@ -158,7 +161,7 @@ print(sprintf("ccccc=%s=ccccc", class(report)))
     expect_true(any(grepl("cw=FALSE", .d)))
     expect_true(any(grepl("cm=TRUE", .d)))
 
-    expect_true(any(grepl("lllll=6=lllll", .e)))
+    expect_true(any(grepl("lllll=9=lllll", .e)))
     expect_true(any(grepl("ccccc=dataquieR_resultset=ccccc", .e)))
     expect_true(any(grepl("pn=dataquieR", .e)))
     expect_true(any(grepl("cc=FALSE", .e)))
@@ -166,7 +169,7 @@ print(sprintf("ccccc=%s=ccccc", class(report)))
     expect_true(any(grepl("cw=TRUE", .e)))
     expect_true(any(grepl("cm=FALSE", .e)))
 
-    expect_true(any(grepl("lllll=6=lllll", .f)))
+    expect_true(any(grepl("lllll=9=lllll", .f)))
     expect_true(any(grepl("ccccc=dataquieR_resultset=ccccc", .f)))
     expect_true(any(grepl("pn=dataquieR", .f)))
     expect_true(any(grepl("cc=FALSE", .f)))
@@ -175,31 +178,35 @@ print(sprintf("ccccc=%s=ccccc", class(report)))
     expect_true(any(grepl("cm=FALSE", .f)))
 
   }
-  fkt2(report, v)
-  f <- fkt(report, v)
+  expect_warning({
+    fkt2(report, v)
+    f <- fkt(report, v)
+  }, regexp = "(No output directory given.*|self-contained = TRUE.*)")
   expect_equal(f, env$file)
   skip_on_cran()
   expect_gt(file.size(env$file), 5000000)
 })
 
 test_that("class ReportSummaryTable", {
-  load(system.file("extdata", "study_data.RData", package = "dataquieR"))
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
   sd1 <- study_data
-  load(system.file("extdata", "meta_data.RData", package = "dataquieR"))
   md1 <- meta_data
-  code_labels <- read.csv2(system.file("extdata",
-                                       "Missing-Codes-2020.csv",
-                                       package = "dataquieR"),
-                           stringsAsFactors = FALSE, na.strings = c())
+  code_labels <- prep_get_data_frame(
+    "meta_data_v2|missing_table")
+
+  md1 <- prep_add_cause_label_df(md1, code_labels)
 
   item_miss <- com_item_missingness(study_data      = sd1,
                                     meta_data       = md1,
                                     label_col       = 'LABEL',
                                     show_causes     = TRUE,
-                                    cause_label_df  = code_labels,
                                     include_sysmiss = TRUE,
                                     threshold_value = 80,
-                                    suppressWarnings = TRUE
+                                    suppressWarnings = TRUE,
+                                    drop_levels = TRUE,
+                                    assume_consistent_codes = TRUE,
+                                    expand_codes = TRUE
   )
   apm <- pro_applicability_matrix(study_data, meta_data)
 
@@ -208,10 +215,12 @@ test_that("class ReportSummaryTable", {
                                      meta_data       = md1,
                                      label_col       = 'LABEL',
                                      show_causes     = TRUE,
-                                     cause_label_df  = code_labels,
                                      include_sysmiss = TRUE,
                                      threshold_value = 80,
-                                     suppressWarnings = TRUE
+                                     suppressWarnings = TRUE,
+                                     drop_levels = !TRUE,
+                                     assume_consistent_codes = TRUE,
+                                     expand_codes = TRUE
   )
 
   item_misss <- com_item_missingness(study_data      = sd1,
@@ -219,10 +228,12 @@ test_that("class ReportSummaryTable", {
                                      meta_data       = md1,
                                      label_col       = 'LABEL',
                                      show_causes     = TRUE,
-                                     cause_label_df  = code_labels,
                                      include_sysmiss = TRUE,
                                      threshold_value = 80,
-                                     suppressWarnings = TRUE
+                                     suppressWarnings = TRUE,
+                                     drop_levels = !TRUE,
+                                     assume_consistent_codes = TRUE,
+                                     expand_codes = TRUE
   )
 
   item_missa <- com_item_missingness(study_data      = sd1,
@@ -230,10 +241,12 @@ test_that("class ReportSummaryTable", {
                                      meta_data       = md1,
                                      label_col       = 'LABEL',
                                      show_causes     = TRUE,
-                                     cause_label_df  = code_labels,
                                      include_sysmiss = TRUE,
                                      threshold_value = 80,
-                                     suppressWarnings = TRUE
+                                     suppressWarnings = TRUE,
+                                     drop_levels = !TRUE,
+                                     assume_consistent_codes = TRUE,
+                                     expand_codes = TRUE
   )
 
   item_missb <- com_item_missingness(study_data      = sd1,
@@ -241,10 +254,12 @@ test_that("class ReportSummaryTable", {
                                      meta_data       = md1,
                                      label_col       = 'LABEL',
                                      show_causes     = TRUE,
-                                     cause_label_df  = code_labels,
                                      include_sysmiss = TRUE,
                                      threshold_value = 80,
-                                     suppressWarnings = TRUE
+                                     suppressWarnings = TRUE,
+                                     drop_levels = !TRUE,
+                                     assume_consistent_codes = TRUE,
+                                     expand_codes = TRUE
   )
 
   item_miss_combined <- rbind(item_missa$ReportSummaryTable,
@@ -263,10 +278,12 @@ test_that("class ReportSummaryTable", {
      meta_data       = md1,
      label_col       = 'LABEL',
      show_causes     = TRUE,
-     cause_label_df  = code_labels,
      include_sysmiss = FALSE,
      threshold_value = 80,
-     suppressWarnings = TRUE
+     suppressWarnings = TRUE,
+     drop_levels = TRUE,
+     assume_consistent_codes = TRUE,
+     expand_codes = TRUE
   )
 
 
@@ -287,14 +304,14 @@ test_that("class ReportSummaryTable", {
     expect_gt(object.size(w), size_min)
     expect_lt(object.size(w), size_max)
   }
-  fkt2(item_miss_emtpy$ReportSummaryTable,
-       size_max = 42000, size_min = 0)
+  expect_warning(fkt2(item_miss_emtpy$ReportSummaryTable,
+       size_max = 42000, size_min = 0), regexp = "Empty result")
   fkt2(item_miss_combined, size_min = 50000,
        size_max = 70000)
   fkt2(item_missa$ReportSummaryTable, size_min = 40000,
        size_max = 50000)
   fkt2(item_missb$ReportSummaryTable, size_min = 50000,
-       size_max = 60000)
+       size_max = 70000)
   fkt2(item_missc$ReportSummaryTable, size_min = 40000,
        size_max = 50000)
   fkt2(item_misss$ReportSummaryTable, size_min = 40000,
@@ -310,14 +327,51 @@ test_that("class ReportSummaryTable", {
                                           dt = FALSE))
   g3 <- R.devices::suppressGraphics(print(item_missa$ReportSummaryTable,
                                           dt = FALSE))
-  g4 <- R.devices::suppressGraphics(print(item_miss_emtpy$ReportSummaryTable,
-                                          dt = FALSE))
+  g4 <- expect_warning(R.devices::suppressGraphics(print(item_miss_emtpy$ReportSummaryTable,
+                                          dt = FALSE)), regexp = "Empty result")
 
+  skip_on_cran()
   skip_if_not_installed("vdiffr")
   skip_if_not(capabilities()["long.double"])
   vdiffr::expect_doppelganger("app-ex-repsumtab", g1)
   vdiffr::expect_doppelganger("im-ex1-repsumtab", g2)
   vdiffr::expect_doppelganger("im-ex2-repsumtab", g3)
-  vdiffr::expect_doppelganger("im-empty-repsumtab", g4)
+  expect_warning(vdiffr::expect_doppelganger("im-empty-repsumtab", g4),
+    regexp = "Empty result")
 
 })
+
+test_that("print.interval works", {
+  withr::local_locale(c(LC_TIME = "en_US.UTF-8"))
+  withr::local_timezone("Europe/Berlin")
+  expect_output(
+    print(util_parse_interval("(1;)")),
+    "(1;Inf)",
+    fixed = TRUE
+  )
+  expect_output(
+    print(util_parse_interval("[1;)")),
+    "[1;Inf)",
+    fixed = TRUE
+  )
+  expect_output(
+    print(util_parse_interval("[1;]")),
+    "[1;Inf]",
+    fixed = TRUE
+  )
+  expect_output(
+    print(util_parse_interval("(2001-01-01;)")),
+    "(2001-01-01;Inf)",
+    fixed = TRUE
+  )
+  expect_output(
+    print(util_parse_interval("[2001-01-01;)")),
+    "[2001-01-01;Inf)",
+    fixed = TRUE
+  )
+  expect_output(
+    print(util_parse_interval("[2001-01-01;]")),
+    "[2001-01-01;Inf]",
+    fixed = TRUE
+  )
+})
