@@ -1,8 +1,12 @@
 test_that("pro_applicability_matrix works", {
-  load(system.file("extdata/meta_data.RData", package = "dataquieR"), envir =
-         environment())
-  load(system.file("extdata/study_data.RData", package = "dataquieR"), envir =
-         environment())
+  skip_on_cran() # deprecated
+  skip_if_not_installed("withr")
+  withr::local_options(dataquieR.CONDITIONS_WITH_STACKTRACE = TRUE,
+                   dataquieR.ERRORS_WITH_CALLER = TRUE,
+                   dataquieR.WARNINGS_WITH_CALLER = TRUE,
+                   dataquieR.MESSAGES_WITH_CALLER = TRUE)
+  meta_data <- prep_get_data_frame("meta_data")
+  study_data <- prep_get_data_frame("study_data")
 
   for (max_vars_per_plot in list(
     1:10, -1, -Inf, NA, NaN, complex(real = 1), "A", letters
@@ -39,8 +43,7 @@ test_that("pro_applicability_matrix works", {
                                           max_vars_per_plot =
                                             max_vars_per_plot),
     regexp =
-      paste("The attribute DATA_TYPE is not contained in the metadata",
-            "but is required for this function."),
+      paste("Missing columns .+DATA_TYPE.+ from .+meta_data.+"),
     perl = TRUE)
 
   md0 <- meta_data
@@ -83,14 +86,17 @@ test_that("pro_applicability_matrix works", {
   )
 
   md0 <- meta_data
-  md0$KEY_STUDY_SEGMENT[[2]] <- NA
+  if (KEY_STUDY_SEGMENT %in% names(md0))
+    md0[[KEY_STUDY_SEGMENT]][[2]] <- NA
+  if (STUDY_SEGMENT %in% names(md0))
+    md0[[STUDY_SEGMENT]][[2]] <- NA
   expect_warning(
     appmatrix <- pro_applicability_matrix(study_data = study_data,
                                           meta_data = md0,
                                           label_col = LABEL,
                                           split_segments = TRUE),
     regexp =
-      paste("Some KEY_STUDY_SEGMENTS are NA.",
+      paste("Some STUDY_SEGMENT are NA.",
             "Will assign those to an artificial segment .+Other.+"),
     all = TRUE,
     perl = TRUE
@@ -103,7 +109,7 @@ test_that("pro_applicability_matrix works", {
                                           split_segments = TRUE,
                                           max_vars_per_plot = 2),
     regexp =
-      paste("n pro_applicability_matrix: Will split segemnt",
+      paste(".*Will split segemnt",
             ".+ arbitrarily avoiding too large figures"),
     all = TRUE,
     perl = TRUE
@@ -112,12 +118,13 @@ test_that("pro_applicability_matrix works", {
 
   md0 <- meta_data
   md0$KEY_STUDY_SEGMENT <- NULL
+  md0$STUDY_SEGMENT <- NULL
   expect_warning(
     appmatrix <- pro_applicability_matrix(study_data = study_data,
                                           meta_data = md0,
                                           label_col = LABEL,
                                           split_segments = TRUE),
-    regexp = paste("Stratification for KEY_STUDY_SEGMENTS is not",
+    regexp = paste("Stratification for STUDY_SEGMENT is not",
                    "possible due to missing metadata. Will split arbitrarily",
                    "avoiding too large figures"),
     perl = TRUE,
@@ -131,7 +138,7 @@ test_that("pro_applicability_matrix works", {
   expect_length(appmatrix$ApplicabilityPlotList, 5)
   expect_lt(abs(suppressWarnings(sum(na.rm = TRUE,
     as.numeric(as.matrix(appmatrix$SummaryTable))
-  )) - 2225), 5)
+  )) - 3149), 5)
 
   skip_on_cran()
   skip_if_not_installed("vdiffr")
