@@ -1,4 +1,5 @@
 test_that("util_app_iav works", {
+  skip_on_cran() # deprecated
   md <- prep_create_meta(
     VAR_NAMES = letters,
     DATA_TYPE = c(rep(DATA_TYPES$FLOAT, 13), rep(DATA_TYPES$INTEGER, 10),
@@ -8,5 +9,5 @@ test_that("util_app_iav works", {
       c(rep("[0;9)", 10), rep(NA, 6), rep("", 10))
   )
   expect_equal(util_app_iav(md, as.factor(rep(1, nrow(md)))),
-               as.factor(c(rep(2, 23), rep(4, 3))))
+               as.factor(c(rep(2, 23), 4, 2, 4)))
 })
